@@ -5,7 +5,8 @@ NULL
 #' @inheritParams ggboxplot
 #' @inheritParams facet
 #' @inheritParams ggpar
-#' @param x,y x and y variables for drawing.
+#' @param x x variables for drawing.
+#' @param y y variables for drawing.
 #' @param color,fill point colors.
 #' @param shape point shape. See \code{\link{show_point_shapes}}.
 #' @param point logical value. If TRUE, show points.
@@ -257,8 +258,8 @@ ggscatter_core <- function(data, x, y,
 
   # Adjust shape when ngroups > 6, to avoid ggplot warnings
   if(shape %in% colnames(data)){
-    ngroups <- length(levels(data[, shape]))
-    if(ngroups > 6) p <- p + scale_shape_manual(values=1:ngroups, labels = levels(data[, shape]))
+    ngroups <- length(levels(data[[shape]]))
+    if(ngroups > 6) p <- p + scale_shape_manual(values=1:ngroups, labels = levels(data[[shape]]))
   }
 
   # Add marginal rug
@@ -282,6 +283,7 @@ ggscatter_core <- function(data, x, y,
     mapping <- .args$mapping
     option <- .args$option
     option[["method"]] <- add
+    option[["formula"]] <- y ~ x
     option[["mapping"]] <- create_aes(mapping)
     p <- p + do.call(geom_smooth, option)
   }
@@ -300,7 +302,7 @@ ggscatter_core <- function(data, x, y,
     # Case of grouping variable
     else {
       grp_name <- grp
-      data[, grp_name] <- as.factor(data[, grp_name])
+      data[[grp_name]] <- as.factor(data[[grp_name]])
     }
 
     if (ellipse.type == 'convex')
@@ -342,10 +344,11 @@ ggscatter_core <- function(data, x, y,
     lab_data <- data
     # Select some labels to show
     if(!is.null(label.select))
-      lab_data  <- subset(lab_data, lab_data[, label, drop = TRUE] %in% label.select,
+      lab_data  <- subset(lab_data, lab_data[[label]] %in% label.select,
                           drop = FALSE)
 
     if(repel){
+      max.overlaps = getOption("ggrepel.max.overlaps", default = Inf)
       ggfunc <- ggrepel::geom_text_repel
       if(label.rectangle) ggfunc <- ggrepel::geom_label_repel
         p <- p + .geom_exec(ggfunc, data = lab_data, x = x, y = y,
@@ -355,7 +358,8 @@ ggscatter_core <- function(data, x, y,
                           alpha = alpha, family = font.family,
                           box.padding = unit(0.35, "lines"),
                           point.padding = unit(0.3, "lines"),
-                          force = 1, show.legend = show.legend.text, seed=123)
+                          force = 1, show.legend = show.legend.text, seed=123,
+                          max.overlaps = max.overlaps)
     }
     else{
       ggfunc <- geom_text
@@ -402,7 +406,7 @@ ggscatter_core <- function(data, x, y,
 .convex_ellipse <- function(data, x, y, grp_name, color = "black", fill = "lightgray", alpha = 0.1,
                             ellipse.border.remove = FALSE ){
 
-  grp_levels <- levels(data[, grp_name])
+  grp_levels <- levels(data[[grp_name]])
   if(length(grp_levels) == 1) .geom_exec(geomfunc = stat_chull, data = data,
                                          color = color, fill = fill, alpha = alpha,
                                          geom = "polygon")
@@ -418,7 +422,7 @@ ggscatter_core <- function(data, x, y,
 # Confidence ellipse
 .confidence_ellipse <- function(data, x, y, grp_name, color = "black", fill = "lightgray",
                                 alpha = 0.1, level = 0.95, ellipse.border.remove = FALSE){
-  grp_levels <- levels(data[, grp_name])
+  grp_levels <- levels(data[[grp_name]])
   if(length(grp_levels) == 1) {
     mapping <- create_aes(list(x = x, y = y))
     stat_conf_ellipse(mapping = mapping, data = data,
@@ -440,7 +444,7 @@ ggscatter_core <- function(data, x, y,
 .stat_ellipse <- function(data, x, y, grp_name, color = "black", fill = "lightgray",
                           alpha = 0.1, type = "norm", level = 0.95, ellipse.border.remove = FALSE)
   {
-  grp_levels <- levels(data[, grp_name])
+  grp_levels <- levels(data[[grp_name]])
   if(length(grp_levels) == 1){
     mapping <- create_aes(list(x = x, y = y))
     ggplot2::stat_ellipse(mapping = mapping, data = data,
